==> odoo_addon_l10n_br_fiscal-16.0.2.18.1-py3-none-any.whl: odoo/addons/l10n_br_fiscal/demo/__init__.py <==
# License AGPL-3 - See http://www.gnu.org/licenses/agpl-3.0.html

DEMO_NCM = [
    # NCMs used in demo products and tests:
    "ncm_00000000",
    "ncm_94013090",
    "ncm_94052000",
    "ncm_94033000",
    "ncm_73269090",
    "ncm_73239900",
    "ncm_94031000",
    "ncm_96100000",
    "ncm_94016100",
    "ncm_72132000",
    "ncm_48191000",
    "ncm_85030010",
    "ncm_27160000",
    "ncm_85014029",
    "ncm_94012000",
    "ncm_22030000",
    "ncm_22040000",
    "ncm_22050000",
    "ncm_22060000",
    "ncm_22080000",
    "ncm_24020000",
    "ncm_24030000",
    "ncm_33030000",
    "ncm_33040000",
    "ncm_33050000",
    "ncm_33070000",
    "ncm_43000000",
    "ncm_93000000",
    "ncm_24010000",
    "ncm_72131000",
    "ncm_72132000",
    "ncm_72142000",
    "ncm_72149100",
    "ncm_72149910",
    "ncm_72149990",
    "ncm_72161000",
    "ncm_72162100",
    "ncm_72162200",
    "ncm_72163100",
    "ncm_72163200",
    "ncm_72171090",
    "ncm_73084000",
    "ncm_73142000",
    "ncm_73143100",
    "ncm_73143900",
    "ncm_73144100",
    "ncm_73144200",
    "ncm_72172090",
    "ncm_72179000",
    "ncm_73130000",
    "ncm_73170020",
    "ncm_73170090",
    "ncm_73262000",
    "ncm_32149000",
    "ncm_69049000",
    "ncm_69051000",
    "ncm_68101900",
    "ncm_68109100",
    "ncm_68109900",
    "ncm_68101100",
    "ncm_68111000",
    "ncm_68112000",
    "ncm_68119000",
    "ncm_69101000",
    "ncm_69109000",
    "ncm_94010000",
    "ncm_94030000",
    "ncm_69060000",
    "ncm_39181000",
    "ncm_44101900",
    "ncm_44111100",
    "ncm_44111900",
    "ncm_44112100",
    "ncm_44112900",
    "ncm_940100000",
    "ncm_940300000",
    "ncm_940410000",
    "ncm_940420000",
    "ncm_392190100",
    "ncm_190520000",
    "ncm_190590900",
    "ncm_190540000",
    "ncm_36041000",
    "ncm_85093000",
    "ncm_90051000",
    "ncm_95044000",
    "ncm_95065100",
    "ncm_95066100",
    "ncm_95063100",
    "ncm_95063200",
    "ncm_96142000",
    "ncm_96159000",
    "ncm_95066100",
    "ncm_24011010",
    "ncm_24011020",
    "ncm_24011030",
    "ncm_24011040",
    "ncm_24011090",
    "ncm_24012010",
    "ncm_24012020",
    "ncm_24012030",
    "ncm_24012040",
    "ncm_24012090",
    "ncm_24013000",
    "ncm_24021000",
    "ncm_24021000_01",
    "ncm_24022000",
    "ncm_24022000_01",
    "ncm_24029000",
    "ncm_24029000_01",
    "ncm_24031100",
    "ncm_24031900",
    "ncm_24039100",
    "ncm_24039910",
    "ncm_24039990",
    "ncm_84714900",
    "ncm_10085090",
    # some other common NCMs:
    "ncm_85171231",
    "ncm_85287200",
    "ncm_84182100",
    "ncm_84151090",
    "ncm_87032100",
    "ncm_09012100",
    "ncm_17019900",
    "ncm_10063021",
    "ncm_33051000",
    "ncm_34022000",
    "ncm_22011000",
]

DEMO_NBM = [  # some common NBMs:
    "nbm_8703210100",
    "nbm_8703210100",
    "nbm_8471490100",
    "nbm_8517120100",
    "nbm_8471500100",
    "nbm_8471500100",
    "nbm_8471600100",
    "nbm_8703400100",
    "nbm_8517690100",
]


DEMO_NBS = [
    "nbs_114021100",
    "nbs_101011000",
    "nbs_101012000",
    "nbs_101021000",
    "nbs_101022000",
    "nbs_101029000",
    "nbs_101031000",
    "nbs_101032000",
    "nbs_101261000",
    "nbs_101262000",
    "nbs_101263000",
    "nbs_101264000",
    "nbs_101269000",
    "nbs_101271000",
    "nbs_101272000",
    "nbs_101281000",
    "nbs_103011000",
    "nbs_103012100",
    "nbs_103012200",
    "nbs_103012900",
    "nbs_103013100",
    "nbs_103013200",
    "nbs_103013900",
    "nbs_103019000",
    "nbs_103020000",
    "nbs_103031100",
    "nbs_115069000",
    "nbs_119031100",
    "nbs_119031200",
    "nbs_120013912",
    "nbs_124043300",
]


DEMO_CEST = [
    "cest_2112400",
    "cest_2106500",
    "cest_2106600",
    "cest_2106700",
    "cest_2106701",
    "cest_2106800",
    "cest_2106900",
    "cest_2107000",
    "cest_2107100",
    "cest_2107200",
    "cest_2107300",
    "cest_2107400",
    "cest_2107500",
    "cest_0112500",
    "cest_0112600",
    "cest_0112700",
    "cest_0112800",
    "cest_0199900",
    "cest_0200100",
    "cest_0200200",
    "cest_0200300",
    "cest_0200400",
    "cest_0200500",
    "cest_0200600",
    "cest_0200700",
    "cest_0200800",
    "cest_0200900",
    "cest_0201000",
    "cest_0100100",
    "cest_1703000",
    "cest_1705602",
    "cest_1709700",
    "cest_2112300",
]

==> odoo_addon_l10n_br_fiscal-18.0.3.1.0-py3-none-any.whl: odoo/addons/l10n_br_fiscal/demo/__init__.py <==
# License AGPL-3 - See http://www.gnu.org/licenses/agpl-3.0.html

DEMO_NCM = [
    # NCMs used in demo products and tests:
    "ncm_00000000",
    "ncm_94013090",
    "ncm_94052000",
    "ncm_94033000",
    "ncm_73269090",
    "ncm_73239900",
    "ncm_94031000",
    "ncm_96100000",
    "ncm_94016100",
    "ncm_72132000",
    "ncm_48191000",
    "ncm_85030010",
    "ncm_27160000",
    "ncm_85014029",
    "ncm_94012000",
    "ncm_22030000",
    "ncm_22040000",
    "ncm_22050000",
    "ncm_22060000",
    "ncm_22080000",
    "ncm_24020000",
    "ncm_24030000",
    "ncm_33030000",
    "ncm_33040000",
    "ncm_33050000",
    "ncm_33070000",
    "ncm_43000000",
    "ncm_93000000",
    "ncm_24010000",
    "ncm_72131000",
    "ncm_72132000",
    "ncm_72142000",
    "ncm_72149100",
    "ncm_72149910",
    "ncm_72149990",
    "ncm_72161000",
    "ncm_72162100",
    "ncm_72162200",
    "ncm_72163100",
    "ncm_72163200",
    "ncm_72171090",
    "ncm_73084000",
    "ncm_73142000",
    "ncm_73143100",
    "ncm_73143900",
    "ncm_73144100",
    "ncm_73144200",
    "ncm_72172090",
    "ncm_72179000",
    "ncm_73130000",
    "ncm_73170020",
    "ncm_73170090",
    "ncm_73262000",
    "ncm_32149000",
    "ncm_69049000",
    "ncm_69051000",
    "ncm_68101900",
    "ncm_68109100",
    "ncm_68109900",
    "ncm_68101100",
    "ncm_68111000",
    "ncm_68112000",
    "ncm_68119000",
    "ncm_69101000",
    "ncm_69109000",
    "ncm_94010000",
    "ncm_94030000",
    "ncm_69060000",
    "ncm_39181000",
    "ncm_44101900",
    "ncm_44111100",
    "ncm_44111900",
    "ncm_44112100",
    "ncm_44112900",
    "ncm_940100000",
    "ncm_940300000",
    "ncm_940410000",
    "ncm_940420000",
    "ncm_392190100",
    "ncm_190520000",
    "ncm_190590900",
    "ncm_190540000",
    "ncm_36041000",
    "ncm_85093000",
    "ncm_90051000",
    "ncm_95044000",
    "ncm_95065100",
    "ncm_95066100",
    "ncm_95063100",
    "ncm_95063200",
    "ncm_96142000",
    "ncm_96159000",
    "ncm_95066100",
    "ncm_24011010",
    "ncm_24011020",
    "ncm_24011030",
    "ncm_24011040",
    "ncm_24011090",
    "ncm_24012010",
    "ncm_24012020",
    "ncm_24012030",
    "ncm_24012040",
    "ncm_24012090",
    "ncm_24013000",
    "ncm_24021000",
    "ncm_24021000_01",
    "ncm_24022000",
    "ncm_24022000_01",
    "ncm_24029000",
    "ncm_24029000_01",
    "ncm_24031100",
    "ncm_24031900",
    "ncm_24039100",
    "ncm_24039910",
    "ncm_24039990",
    "ncm_84714900",
    "ncm_10085090",
    # some other common NCMs:
    "ncm_85171231",
    "ncm_85287200",
    "ncm_84182100",
    "ncm_84151090",
    "ncm_87032100",
    "ncm_09012100",
    "ncm_17019900",
    "ncm_10063021",
    "ncm_33051000",
    "ncm_34022000",
    "ncm_22011000",
]

DEMO_NBM = [
    "nbm_8801100200",
    "nbm_8801900100",
    "nbm_190590",
    "nbm_4014100000",
    "nbm_96032100",
    # some common NBMs:
    "nbm_8703210100",
    "nbm_8703210100",
    "nbm_8471490100",
    "nbm_8517120100",
    "nbm_8471500100",
    "nbm_8471500100",
    "nbm_8471600100",
    "nbm_8703400100",
    "nbm_8517690100",
]


DEMO_NBS = [
    "nbs_114021100",
    "nbs_101011100",
    "nbs_101011200",
    "nbs_101012100",
    "nbs_101022000",
    "nbs_101029000",
    "nbs_101031000",
    "nbs_101032000",
    "nbs_102010000",
    "nbs_102020000",
    "nbs_102030000",
    "nbs_102040000",
    "nbs_102050000",
    "nbs_103012100",
    "nbs_103012200",
    "nbs_103013100",
    "nbs_103011000",
    "nbs_103012100",
    "nbs_103012900",
    "nbs_103013200",
    "nbs_103013900",
    "nbs_103013200",
    "nbs_103019000",
    "nbs_103020000",
    "nbs_103031100",
    "nbs_103031200",
    "nbs_115069000",
    "nbs_119031100",
    "nbs_119031200",
    "nbs_120014000",
    "nbs_124043300",
]


DEMO_CEST = [
    "cest_2112400",
    "cest_2106500",
    "cest_2106600",
    "cest_2106700",
    "cest_2106701",
    "cest_2106800",
    "cest_2106900",
    "cest_2107000",
    "cest_2107100",
    "cest_2107200",
    "cest_2107300",
    "cest_2107400",
    "cest_2107500",
    "cest_0112500",
    "cest_0112600",
    "cest_0112700",
    "cest_0112800",
    "cest_0199900",
    "cest_0200100",
    "cest_0200200",
    "cest_0200300",
    "cest_0200400",
    "cest_0200500",
    "cest_0200600",
    "cest_0200700",
    "cest_0200800",
    "cest_0200900",
    "cest_0201000",
    "cest_0100100",
    "cest_1703000",
    "cest_1705602",
    "cest_1709700",
    "cest_2112300",
]
